' /**
'  * @member initializeLogManager
'  * @memberof module:LogMixin
'  * @instance
'  * @description creates Log manager, and places it on global
'  *              expects to have access to globalNode on m.global (i.e. from within an SG control)
'  * @param {transportTypes} array of transportsType names.
'  *      you can provide your own transport;
'  *      it just hast to be a node that implements the interface function:
'  *
'  *      function logItem(name, levelNum, text) as void
'  *
'  *      built in transports:
'  *      LogNodeTransport - output goes straight to debug print
'  *      LogScreenTransport - output is stored on
'  *      LogPrintTransport - output goes to console
'  *
'  * @param {integer} logLevel
'  *                level of the logging
'  *                0 - ERROR
'  *                1 - WARN
'  *                2 - INFO and METHOD
'  *                3 - VERBOSE
'  *                4 - DEBUG
'  * @returns {RLog} RLog instance for further configuration
'  */
function initializeLogManager(transportTypes = invalid, logLevel = invalid, includeDate = false) as object
    rLog = CreateObject("roSGNode", "Log")
    m.global.addFields({
        "rLog": rLog
    })
    m.top.getScene().addFields({
        "rLog": rLog
    })
    if transportTypes = invalid then
        transportTypes = [
            "log_PrintTransport"
        ]
    end if
    if logLevel = invalid then
        logLevel = 2
    end if
    rlog.transportTypes = transportTypes
    rlog.logLevel = logLevel
    rlog.includeDate = includeDate
    return rLog
end function

function getLogInstance()
    if m.global <> invalid and m.global.rLog <> invalid then
        return m.global.rLog
    end if
    if m.top.getScene() <> invalid then
        'back up to help with some testing scenarios one might encounter
        return m.top.getScene().rLog
    end if
    return invalid
end function
function __Logger_builder()
    instance = {}
    instance.new = function(name = "general") as void
        m.name = invalid
        m.rLog = invalid
        m.name = name
        m.rLog = getLogInstance()
        if m.rLog <> invalid then
            m.rLog_isFiltering = m.rLog.isFiltering
            m.rLog_logLevel = m.rLog.logLevel
            m.rLog_includeFilters = m.rLog.includeFilters
            m.rLog_excludeFilters = m.rLog.excludeFilters
            m.rLog_includeDate = m.rLog.includeDate
            m.rLog_logMode = m.rLog.logMode
            m.rLog_transports = m.rLog.transports
        else
            m.log = function(levelNum, level, message, value = "~#", value2 = "~#", value3 = "~#", value4 = "~#", value5 = "~#", value6 = "~#", value7 = "~#", value8 = "~#", value9 = "~#", isMethod = false) as void
                ? " ERROR  NO LOGGER FOUND IN "; m.top
            end function
        end if
    end function
    instance.log = function(levelNum, level, message, value = "~#", value2 = "~#", value3 = "~#", value4 = "~#", value5 = "~#", value6 = "~#", value7 = "~#", value8 = "~#", value9 = "~#", isMethod = false) as void
        if m.rLog_isFiltering then
            if m.rLog_logLevel < levelNum or (m.rLog_includeFilters.count() > 0 and m.rLog_includeFilters[m.name] = invalid) or (m.rLog_excludeFilters.count() > 0 and m.rLog_excludeFilters[m.name] <> invalid) then
                return
            end if
        end if
        if m.rLog_includeDate then
            level = m.rLog.dateText + " " + level
        end if
        if m.rLog_logMode = 1 then
            print level; " "; m.toString(message); " "; m.toString(value); " "; m.toString(value2); " "; m.toString(value3); " "; m.toString(value4) " "; m.toString(value5); " "; m.toString(value6); " "; m.toString(value7); " "; m.toString(value8); " " + m.toString(value9)
        else
            text = level + " " + m.toString(message) + " " + m.toString(value) + " " + m.toString(value2) + " " + m.toString(value3) + " " + m.toString(value4) + " " + m.toString(value5) + " " + m.toString(value6) + " " + m.toString(value7) + " " + m.toString(value8) + " " + m.toString(value9)
            if m.rLog_logMode = 3 then
                print text
            end if
            for each transport in m.rLog_transports
                transport.callFunc("logItem", m.name, levelNum, text)
            end for
        end if
    end function
    instance.debug = function(message, value = "~#", value2 = "~#", value3 = "~#", value4 = "~#", value5 = "~#", value6 = "~#", value7 = "~#", value8 = "~#", value9 = "~#") as void
        if m.rLog = invalid then
            return
        end if
        m.log(4, "DEBUG", message, value, value2, value3, value4, value5, value6, value7, value8, value9)
    end function
    instance.verbose = function(message, value = "~#", value2 = "~#", value3 = "~#", value4 = "~#", value5 = "~#", value6 = "~#", value7 = "~#", value8 = "~#", value9 = "~#") as void
        if m.rLog = invalid then
            return
        end if
        m.log(3, "VERBOSE", message, value, value2, value3, value4, value5, value6, value7, value8, value9)
    end function
    instance.info = function(message, value = "~#", value2 = "~#", value3 = "~#", value4 = "~#", value5 = "~#", value6 = "~#", value7 = "~#", value8 = "~#", value9 = "~#") as void
        if m.rLog = invalid then
            return
        end if
        m.log(2, "INFO", message, value, value2, value3, value4, value5, value6, value7, value8, value9)
    end function
    instance.method = function(message, value = "~#", value2 = "~#", value3 = "~#", value4 = "~#", value5 = "~#", value6 = "~#", value7 = "~#", value8 = "~#", value9 = "~#") as void
        if m.rLog = invalid then
            return
        end if
        m.log(2, "METHOD", message, value, value2, value3, value4, value5, value6, value7, value8, value9, true)
    end function
    instance.warn = function(message, value = "~#", value2 = "~#", value3 = "~#", value4 = "~#", value5 = "~#", value6 = "~#", value7 = "~#", value8 = "~#", value9 = "~#") as void
        if m.rLog = invalid then
            return
        end if
        m.log(1, "WARN", message, value, value2, value3, value4, value5, value6, value7, value8, value9)
    end function
    instance.error = function(message, value = "~#", value2 = "~#", value3 = "~#", value4 = "~#", value5 = "~#", value6 = "~#", value7 = "~#", value8 = "~#", value9 = "~#") as void
        if m.rLog = invalid then
            return
        end if
        m.log(0, "ERROR", message, value, value2, value3, value4, value5, value6, value7, value8, value9)
    end function
    instance.toString = function(value as dynamic) as string
        valueType = type(value)
        if valueType = "<uninitialized>" then
            return "UNINIT"
        else if value = invalid then
            return "INVALID"
        else if getInterface(value, "ifString") <> invalid then
            if value = "~#" then
                return ""
            else
                return value
            end if
        else if valueType = "roInt" or valueType = "roInteger" or valueType = "Integer" then
            return value.toStr()
        else if getInterface(value, "ifFloat") <> invalid then
            return str(value).trim()
        else if valueType = "roSGNode" then
            return "Node(" + value.subType() + ")"
        else if valueType = "roAssociativeArray" then
            return "AA(" + formatJson(value) + ")"
        else if valueType = "roBoolean" or valueType = "Boolean" then
            return value.toStr()
        else
            return ""
        end if
    end function
    return instance
end function
function Logger(name = "general")
    instance = __Logger_builder()
    instance.new(name)
    return instance
end function'//# sourceMappingURL=./LogMixin.bs.map